@@ -1,5 +1,5 @@
 /*
-% Copyright (C) 2003 - 2012 GraphicsMagick Group
+% Copyright (C) 2003 - 2014 GraphicsMagick Group
 % Copyright (C) 2002 ImageMagick Studio
 %
 % This program is covered by multiple licenses, which are described in
@@ -223,28 +223,27 @@ static CompositeOperator GIMPBlendModeToCompositeOperator( unsigned int blendMod
 {
   switch ( blendMode )
     {
-    case GIMP_NORMAL_MODE:    return( OverCompositeOp );
-    case GIMP_DISSOLVE_MODE:  return( DissolveCompositeOp );
-    case GIMP_MULTIPLY_MODE:  return( MultiplyCompositeOp );
-    case GIMP_SCREEN_MODE:    return( ScreenCompositeOp );
-    case GIMP_OVERLAY_MODE:    return( OverlayCompositeOp );
+    case GIMP_NORMAL_MODE:      return( OverCompositeOp );
+    case GIMP_DISSOLVE_MODE:    return( DissolveCompositeOp );
+    case GIMP_MULTIPLY_MODE:    return( MultiplyCompositeOp );
+    case GIMP_SCREEN_MODE:      return( ScreenCompositeOp );
+    case GIMP_OVERLAY_MODE:     return( OverlayCompositeOp );
     case GIMP_DIFFERENCE_MODE:  return( DifferenceCompositeOp );
-    case GIMP_ADDITION_MODE:  return( AddCompositeOp );
-    case GIMP_SUBTRACT_MODE:  return( SubtractCompositeOp );
-    case GIMP_DARKEN_ONLY_MODE:  return( DarkenCompositeOp );
+    case GIMP_ADDITION_MODE:    return( AddCompositeOp );
+    case GIMP_SUBTRACT_MODE:    return( SubtractCompositeOp );
+    case GIMP_DARKEN_ONLY_MODE: return( DarkenCompositeOp );
     case GIMP_LIGHTEN_ONLY_MODE:return( LightenCompositeOp );
-    case GIMP_HUE_MODE:      return( HueCompositeOp );
+    case GIMP_HUE_MODE:         return( HueCompositeOp );
     case GIMP_SATURATION_MODE:  return( SaturateCompositeOp );
-    case GIMP_COLOR_MODE:    return( ColorizeCompositeOp );
-    case GIMP_DIVIDE_MODE:    return( DivideCompositeOp );
-      /* these are the ones we don't support...yet */
-    case GIMP_DODGE_MODE:    return( OverCompositeOp );
-    case GIMP_BURN_MODE:    return( OverCompositeOp );
-    case GIMP_HARDLIGHT_MODE:  return( OverCompositeOp );
-    case GIMP_BEHIND_MODE:    return( OverCompositeOp );
-    case GIMP_VALUE_MODE:    return( OverCompositeOp );
-    default:
-      return( OverCompositeOp );
+    case GIMP_COLOR_MODE:       return( ColorizeCompositeOp );
+    case GIMP_DIVIDE_MODE:      return( DivideCompositeOp );
+    case GIMP_HARDLIGHT_MODE:   return( HardLightCompositeOp );
+    case GIMP_DODGE_MODE:       return( ColorDodgeCompositeOp );
+    case GIMP_BURN_MODE:        return( ColorBurnCompositeOp );
+    /* these are the ones we don't support...yet */
+    case GIMP_BEHIND_MODE:      return( OverCompositeOp );
+    case GIMP_VALUE_MODE:       return( OverCompositeOp );
+    default:                    return( OverCompositeOp );
     }
 }
 
@@ -986,7 +985,7 @@ static MagickPassFail load_hierarchy (Image *image, XCFDocInfo* inDocInfo, XCFLa
 static MagickPassFail ReadOneLayer( Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
                                     outLayer )
 {
-  int
+  unsigned int
     i;
 
   unsigned int
@@ -1025,7 +1024,7 @@ static MagickPassFail ReadOneLayer( Image* image, XCFDocInfo* inDocInfo, XCFLaye
   while ( !foundPropEnd && !EOFBlob(image) )
     {
       PropType    prop_type = (PropType) ReadBlobMSBLong(image);
-      unsigned long  prop_size = ReadBlobMSBLong(image);
+      size_t      prop_size = ReadBlobMSBLong(image);
 
       switch (prop_type)
         {
@@ -1071,7 +1070,7 @@ static MagickPassFail ReadOneLayer( Image* image, XCFDocInfo* inDocInfo, XCFLaye
           break;
         case PROP_PARASITES:
           {
-            for (i=0; i < (long) prop_size; i++ )
+            for (i=0; i < prop_size; i++ )
               if (ReadBlobByte(image) == EOF)
                 break;
 
@@ -1101,7 +1100,7 @@ static MagickPassFail ReadOneLayer( Image* image, XCFDocInfo* inDocInfo, XCFLaye
             while (prop_size > 0 && !EOFBlob(image))
               {
                 amount = Min (16, prop_size);
-                for (i=0; i < (long) amount; i++)
+                for (i=0; i < amount; i++)
                   if (ReadBlob(image, amount, &buf) != amount)
                     break;
                 prop_size -= Min (16, amount);
@@ -1340,7 +1339,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 (doc_info.compression != COMPRESS_RLE) &&
                 (doc_info.compression != COMPRESS_ZLIB) &&
                 (doc_info.compression != COMPRESS_FRACTAL))
-              ThrowReaderException(CorruptImageWarning,CompressionNotValid,image);
+              ThrowReaderException(CorruptImageError,CompressionNotValid,image);
           }
           break;
 
