@@ -17,7 +17,7 @@ PACKAGE_BUGREPORT='graphicsmagick-bugs@lists.sourceforge.net'
 
 # Package base version.  This is is the numeric version suffix applied to
 # PACKAGE_NAME (e.g. "1.2").
-PACKAGE_VERSION='1.3.19'
+PACKAGE_VERSION='1.3.21'
 
 #
 # Package name plus version string.
@@ -27,7 +27,7 @@ PACKAGE_STRING="$PACKAGE_NAME $PACKAGE_VERSION"
 #
 # Formal Package release date
 # Set to string "unreleased" if package is not a formal release.
-PACKAGE_RELEASE_DATE="2013-12-31"
+PACKAGE_RELEASE_DATE="2015-02-28"
 #PACKAGE_RELEASE_DATE="unreleased"
 
 #
@@ -50,7 +50,7 @@ fi
 #
 # Mercurial branch that this release is on.
 #
-HG_BRANCH_TAG=default
+HG_BRANCH_TAG=GraphicsMagick-1_3
 
 #
 # Libtool library revision control info
@@ -86,21 +86,21 @@ HG_BRANCH_TAG=default
 #
 # Magick library versioning
 #
-MAGICK_LIBRARY_CURRENT=14
+MAGICK_LIBRARY_CURRENT=16
 
-MAGICK_LIBRARY_REVISION=1
-MAGICK_LIBRARY_AGE=11
+MAGICK_LIBRARY_REVISION=0
+MAGICK_LIBRARY_AGE=13
 
 #
 # Magick++ library versioning
 #
-MAGICK_PLUS_PLUS_LIBRARY_CURRENT=9
-MAGICK_PLUS_PLUS_LIBRARY_REVISION=3
-MAGICK_PLUS_PLUS_LIBRARY_AGE=6
+MAGICK_PLUS_PLUS_LIBRARY_CURRENT=11
+MAGICK_PLUS_PLUS_LIBRARY_REVISION=0
+MAGICK_PLUS_PLUS_LIBRARY_AGE=0
 
 #
 # Magick Wand library versioning
 #
-MAGICK_WAND_LIBRARY_CURRENT=8
+MAGICK_WAND_LIBRARY_CURRENT=9
 MAGICK_WAND_LIBRARY_REVISION=1
-MAGICK_WAND_LIBRARY_AGE=6
+MAGICK_WAND_LIBRARY_AGE=7
